==> ec_live_subproducts-5.x-2.04.tar.gz: ec_live_subproducts/ec_live_subproducts developer.js <==
// equivalen to E-Commerce (PHP) FormatPayment function
// its faster than use ajax to format the number
function FormatPayment(price, decimal_pos, thousand, decimal, symbol, symbol_pos) {
  price = Math.round(price * Math.pow(10, decimal_pos)) / Math.pow(10, decimal_pos);
  f = price + "";
  f = f.split(".");
  if (!f[0]) {f[0] = "0";}
  if (!f[1]) {f[1] = "";}
  if (f[1].length < decimal_pos) {
    g = f[1];
    for (i=f[1].length + 1; i <= decimal_pos; i++) {g += "0";}
    f[1] = g;
  }
  if (thousand != "" && f[0].length > 3) {
    h = f[0];
    f[0] = "";
    for(j = 3; j < h.length; j+=3) {
      i = h.slice(h.length - j, h.length - j + 3);
      f[0] = thousand + i + f[0] + "";
    }
    j = h.substr(0, (h.length % 3 == 0) ? 3 : (h.length % 3));
    f[0] = j + f[0];
  }
  decimal = (decimal_pos <= 0) ? "" : decimal;
  if (symbol_pos == 1) return symbol + f[0] + decimal + f[1];
  else return f[0] + decimal + f[1] + symbol;
}

function RefreshPrices() {
  var forbidden = new Array;
  var categories = new Array;
  var price = Drupal.settings.baseprice;
  var stock = -1;
  var forbid = false;
  $(".selectattribute").each(function(i) {
    if (this.checked) {
      $("#description-" + this.name.replace(/variations\[/, "").replace(/\]/, "")).html(attribute[this.value]["description"]);
      price += attribute[this.value]["price"];
      forbidden = forbidden.concat(attribute[this.value]["forbidden"].split(","));
      categories = categories.concat(attribute[this.value]["category"].split(","));
      if ((stock > attribute[this.value]["stock"] && attribute[this.value]["stock"] != -1) || (stock == -1 && stock < attribute[this.value]["stock"]) ) {stock = attribute[this.value]["stock"];}
    }
  });
  $(".selectattribute").filter(".form-select").each(function(i) {
    $("#description-" + this.name.replace(/variations\[/, "").replace(/\]/, "")).html(attribute[this.value]["description"]);
    price += attribute[this.value]["price"];
    forbidden = forbidden.concat(attribute[this.value]["forbidden"].split(","));
    categories = categories.concat(attribute[this.value]["category"].split(","));
    if ((stock > attribute[this.value]["stock"] && attribute[this.value]["stock"] != -1) || (stock == -1 && stock < attribute[this.value]["stock"]) ) {stock = attribute[this.value]["stock"];}
  });
  f_len = forbidden.length;
  c_len = categories.length;
  for (f=0; f < f_len; f++) {
    for (c=0; c < c_len; c++) {
      if (categories[c] == forbidden[f] && categories[c] != "") {
        stock = 0;
        forbid = true;
        break;
      }
    }
  }
  if (forbid) {$("#price > div").html(Drupal.settings.messages["forbidden"]);}
  else {
    if (stock != 0) {
      $("#price > div").html("<LABEL>" + Drupal.settings.messages["price"] + ": </LABEL>" + FormatPayment(price, Drupal.settings.payment_format["decimal_places"], Drupal.settings.payment_format["thousand"], Drupal.settings.payment_format["decimal"], Drupal.settings.payment_format["symbol"], Drupal.settings.payment_format["symbol_position"]))
    }
    else {$("#price > div").html(Drupal.settings.messages["sold_out"]);}
  }
  $("#edit-add-to-cart").attr("disabled", !stock);
}

function RefreshPricesStart() {
  attribute = Drupal.settings.attribute;
  $("#edit-priceupdate").css("display", "none");
  $(".selectattribute").change(function() {RefreshPrices ();});
  $("#price").css("right", "5px").css("top", (window.outerHeight / 2) + "px").css("position", "fixed");
  RefreshPrices();
}

$(document).ready(function() {RefreshPricesStart();})

==> ec_live_subproducts-5.x-2.06.tar.gz: ec_live_subproducts/ec_live_subproducts developer.js <==
// equivalen to E-Commerce (PHP) FormatPayment function
// its faster than use ajax to format the number
function FormatPayment(price, decimal_pos, thousand, decimal, symbol, symbol_pos) {
  price = Math.round(price * Math.pow(10, decimal_pos)) / Math.pow(10, decimal_pos);
  f = price + "";
  f = f.split(".");
  if (!f[0]) {f[0] = "0";}
  if (!f[1]) {f[1] = "";}
  if (f[1].length < decimal_pos) {
    g = f[1];
    for (i=f[1].length + 1; i <= decimal_pos; i++) {g += "0";}
    f[1] = g;
  }
  if (thousand != "" && f[0].length > 3) {
    h = f[0];
    f[0] = "";
    for(j = 3; j < h.length; j+=3) {
      i = h.slice(h.length - j, h.length - j + 3);
      f[0] = thousand + i + f[0] + "";
    }
    j = h.substr(0, (h.length % 3 == 0) ? 3 : (h.length % 3));
    f[0] = j + f[0];
  }
  decimal = (decimal_pos <= 0) ? "" : decimal;
  if (symbol_pos == 1) return symbol + f[0] + decimal + f[1];
  else return f[0] + decimal + f[1] + symbol;
}

function RefreshPrices() {
  var forbidden = new Array;
  var categories = new Array;
  var price = Drupal.settings.baseprice;
  var stock = -1;
  var forbid = false;
  for(variation in Drupal.settings.attribute) {
    attribute = Drupal.settings.attribute[variation][Drupal.settings.attribute[variation]["checked"]];
    $("#description-" + variation).html(attribute["description"]);
    price += attribute["price"];
    forbidden = forbidden.concat(attribute["forbidden"].split(","));
    categories = categories.concat(attribute["category"].split(","));
    if ((stock > attribute["stock"] && attribute["stock"] != -1) || (stock == -1 && stock < attribute["stock"]) ) {stock = attribute["stock"];}
  }
  f_len = forbidden.length;
  c_len = categories.length;
  for (f=0; f < f_len; f++) {
    for (c=0; c < c_len; c++) {
      if (categories[c] == forbidden[f] && categories[c] != "") {
        stock = 0;
        forbid = true;
        break;
      }
    }
  }
  if (forbid) {$("#price > div").html(Drupal.settings.messages["forbidden"]);}
  else {
    if (stock != 0) {
      $("#price > div").html("<LABEL>" + Drupal.settings.messages["price"] + ": </LABEL>" + FormatPayment(price, Drupal.settings.payment_format["decimal_places"], Drupal.settings.payment_format["thousand"], Drupal.settings.payment_format["decimal"], Drupal.settings.payment_format["symbol"], Drupal.settings.payment_format["symbol_position"]))
    }
    else {$("#price > div").html(Drupal.settings.messages["sold_out"]);}
  }
  $("#edit-add-to-cart").attr("disabled", !stock);
}

function RefreshPricesStart() {
  $("#edit-priceupdate").css("display", "none");
  $(".selectattribute").change(function() {
    if (this.checked || this.type == "select-one" ) {
      Drupal.settings.attribute[this.name.replace(/variations\[/, "").replace(/\]/, "")]["checked"] = this.value;
      RefreshPrices();
    }
  });
  RefreshPrices();
}

$(function() {RefreshPricesStart();})
